---
name: Trestle release template
about: Use this template to execute a trestle release
title: 'chore: Trestle release'
assignees: butler54
---

## Summary

## Quality assurance (all should be covered).

- [ ] My code follows the code style of this project.
- [ ] Documentation for my change is up to date?
- [ ] My PR meets testing requirements.
- [ ] All new and existing tests passed.
- [ ] All commits are signed-off.

## Before you merge

- Ensure it is a 'squash commit'
- Ensure CI is currently passing
- Is this a merge to `main` from any branch except `develop` or `ghpages`?

## After you merge

- Check that the release actually happens.
